==> jc-1.4.0.tar.gz: java/awt/AWTEvent.h <==
// public abstract class java.awt.AWTEvent

// class file dependencies
// @dep_class 8d452c371daaa884 java_awt_AWTEvent
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_AWTEvent_H_
#define _JC_java_awt_AWTEvent_H_

// Forward structure declarations
struct _jc_java_awt_Event$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTEvent$sub_refs	_jc_java_awt_AWTEvent$sub_refs;
typedef struct _jc_java_awt_AWTEvent$sub_nonrefs	_jc_java_awt_AWTEvent$sub_nonrefs;
typedef struct _jc_java_awt_AWTEvent$refs	_jc_java_awt_AWTEvent$refs;
typedef struct _jc_java_awt_AWTEvent$nonrefs	_jc_java_awt_AWTEvent$nonrefs;
typedef struct _jc_java_awt_AWTEvent$object	_jc_java_awt_AWTEvent$object;

typedef struct _jc_java_awt_AWTEvent$fields_struct	_jc_java_awt_AWTEvent$fields_struct;
typedef const struct _jc_java_awt_AWTEvent$vmethods	_jc_java_awt_AWTEvent$vmethods;
typedef const struct _jc_java_awt_AWTEvent$vtable	_jc_java_awt_AWTEvent$vtable;
typedef const struct _jc_java_awt_AWTEvent$vtype	_jc_java_awt_AWTEvent$vtype;

// Class fields structure
struct _jc_java_awt_AWTEvent$fields_struct {
	jlong	ACTION__5fEVENT__5fMASK;
	jlong	ADJUSTMENT__5fEVENT__5fMASK;
	jlong	COMPONENT__5fEVENT__5fMASK;
	jlong	CONTAINER__5fEVENT__5fMASK;
	jlong	FOCUS__5fEVENT__5fMASK;
	jlong	HIERARCHY__5fBOUNDS__5fEVENT__5fMASK;
	jlong	HIERARCHY__5fEVENT__5fMASK;
	jlong	INPUT__5fENABLED__5fEVENT__5fMASK;
	jlong	INPUT__5fMETHOD__5fEVENT__5fMASK;
	jlong	INVOCATION__5fEVENT__5fMASK;
	jlong	ITEM__5fEVENT__5fMASK;
	jlong	KEY__5fEVENT__5fMASK;
	jlong	MOUSE__5fEVENT__5fMASK;
	jlong	MOUSE__5fMOTION__5fEVENT__5fMASK;
	jlong	MOUSE__5fWHEEL__5fEVENT__5fMASK;
	jlong	PAINT__5fEVENT__5fMASK;
	jlong	TEXT__5fEVENT__5fMASK;
	jlong	WINDOW__5fEVENT__5fMASK;
	jlong	WINDOW__5fFOCUS__5fEVENT__5fMASK;
	jlong	WINDOW__5fSTATE__5fEVENT__5fMASK;
	jlong	serialVersionUID;
	jint	RESERVED__5fID__5fMAX;
};
extern _jc_java_awt_AWTEvent$fields_struct _jc_java_awt_AWTEvent$class_fields;

// Constructors
extern void _jc_java_awt_AWTEvent$method$_init$c96d1e291aee3904(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_awt_Event$object *);
extern void _jc_java_awt_AWTEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *, jint);

// Virtual methods
extern void _jc_java_awt_AWTEvent$method$consume$3d554af5733d9795(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
extern jint _jc_java_awt_AWTEvent$method$getID$c4aaaa21bd3c4612(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
extern jboolean _jc_java_awt_AWTEvent$method$isConsumed$98f8b0828fdde4a0(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_AWTEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
extern void _jc_java_awt_AWTEvent$method$setSource$4063475456b19564(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_String$object *_jc_java_awt_AWTEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_AWTEvent$object *);

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTEvent$method_info$consume$3d554af5733d9795;
extern _jc_method _jc_java_awt_AWTEvent$method_info$getID$c4aaaa21bd3c4612;
extern _jc_method _jc_java_awt_AWTEvent$method_info$isConsumed$98f8b0828fdde4a0;
extern _jc_method _jc_java_awt_AWTEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_AWTEvent$method_info$setSource$4063475456b19564;
extern _jc_method _jc_java_awt_AWTEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_AWTEvent$vmethods {
	void	(*consume$3d554af5733d9795)(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
	jint	(*getID$c4aaaa21bd3c4612)(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
	jboolean	(*isConsumed$98f8b0828fdde4a0)(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
	void	(*setSource$4063475456b19564)(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_AWTEvent$object *);
};

// Vtable
struct _jc_java_awt_AWTEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
};

// Vtype
struct _jc_java_awt_AWTEvent$vtype {
	_jc_type			type;
	_jc_java_awt_AWTEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTEvent$sub_refs {
	_jc_byte_array	*bdata;
};

// Reference instance fields (object)
struct _jc_java_awt_AWTEvent$refs {
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTEvent$sub_nonrefs {
	jint	id;
	jboolean	consumed;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
};

// Object instance structure
struct _jc_java_awt_AWTEvent$object {
	_jc_java_awt_AWTEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTEvent$vtype	*vtype;
	_jc_java_awt_AWTEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTEvent$vtype _jc_java_awt_AWTEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTEvent$class_object;

#endif	/* _JC_java_awt_AWTEvent_H_ */

==> jc-1.4.5.tar.gz: java/awt/AWTEvent.h <==
// public abstract class java.awt.AWTEvent

// class file dependencies
// @dep_class e9135e4c9c3f14c9 java_awt_AWTEvent
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class e4988e4c1a7050ab java_util_EventObject

// header file dependencies
// @dep_header java_util_EventObject

#include "java/util/EventObject.h"

#ifndef _JC_java_awt_AWTEvent_H_
#define _JC_java_awt_AWTEvent_H_

// Forward structure declarations
struct _jc_java_awt_Event$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;

// Typedefs
typedef struct _jc_java_awt_AWTEvent$sub_refs	_jc_java_awt_AWTEvent$sub_refs;
typedef struct _jc_java_awt_AWTEvent$sub_nonrefs	_jc_java_awt_AWTEvent$sub_nonrefs;
typedef struct _jc_java_awt_AWTEvent$refs	_jc_java_awt_AWTEvent$refs;
typedef struct _jc_java_awt_AWTEvent$nonrefs	_jc_java_awt_AWTEvent$nonrefs;
typedef struct _jc_java_awt_AWTEvent$object	_jc_java_awt_AWTEvent$object;

typedef struct _jc_java_awt_AWTEvent$fields_struct	_jc_java_awt_AWTEvent$fields_struct;
typedef const struct _jc_java_awt_AWTEvent$vmethods	_jc_java_awt_AWTEvent$vmethods;
typedef const struct _jc_java_awt_AWTEvent$vtable	_jc_java_awt_AWTEvent$vtable;
typedef const struct _jc_java_awt_AWTEvent$vtype	_jc_java_awt_AWTEvent$vtype;

// Class fields structure
struct _jc_java_awt_AWTEvent$fields_struct {
	jlong	ACTION__5fEVENT__5fMASK;
	jlong	ADJUSTMENT__5fEVENT__5fMASK;
	jlong	COMPONENT__5fEVENT__5fMASK;
	jlong	CONTAINER__5fEVENT__5fMASK;
	jlong	FOCUS__5fEVENT__5fMASK;
	jlong	HIERARCHY__5fBOUNDS__5fEVENT__5fMASK;
	jlong	HIERARCHY__5fEVENT__5fMASK;
	jlong	INPUT__5fENABLED__5fEVENT__5fMASK;
	jlong	INPUT__5fMETHOD__5fEVENT__5fMASK;
	jlong	INVOCATION__5fEVENT__5fMASK;
	jlong	ITEM__5fEVENT__5fMASK;
	jlong	KEY__5fEVENT__5fMASK;
	jlong	MOUSE__5fEVENT__5fMASK;
	jlong	MOUSE__5fMOTION__5fEVENT__5fMASK;
	jlong	MOUSE__5fWHEEL__5fEVENT__5fMASK;
	jlong	PAINT__5fEVENT__5fMASK;
	jlong	TEXT__5fEVENT__5fMASK;
	jlong	WINDOW__5fEVENT__5fMASK;
	jlong	WINDOW__5fFOCUS__5fEVENT__5fMASK;
	jlong	WINDOW__5fSTATE__5fEVENT__5fMASK;
	jlong	serialVersionUID;
	jint	RESERVED__5fID__5fMAX;
};
extern _jc_java_awt_AWTEvent$fields_struct _jc_java_awt_AWTEvent$class_fields;

// Constructors
extern void _jc_java_awt_AWTEvent$method$_init$c96d1e291aee3904(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_awt_Event$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_AWTEvent$method$_init$a57db7ba48d4b8bc(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *, jint) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_java_awt_AWTEvent$method$consume$3d554af5733d9795(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
extern jint _jc_java_awt_AWTEvent$method$getID$c4aaaa21bd3c4612(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
extern jboolean _jc_java_awt_AWTEvent$method$isConsumed$98f8b0828fdde4a0(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_AWTEvent$method$paramString$af933b2f56e61fc3(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
extern void _jc_java_awt_AWTEvent$method$setSource$4063475456b19564(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_java_awt_AWTEvent$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_java_awt_AWTEvent$method_info$consume$3d554af5733d9795;
extern _jc_method _jc_java_awt_AWTEvent$method_info$getID$c4aaaa21bd3c4612;
extern _jc_method _jc_java_awt_AWTEvent$method_info$isConsumed$98f8b0828fdde4a0;
extern _jc_method _jc_java_awt_AWTEvent$method_info$paramString$af933b2f56e61fc3;
extern _jc_method _jc_java_awt_AWTEvent$method_info$setSource$4063475456b19564;
extern _jc_method _jc_java_awt_AWTEvent$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_java_awt_AWTEvent$vmethods {
	void	(*consume$3d554af5733d9795)(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
	jint	(*getID$c4aaaa21bd3c4612)(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
	jboolean	(*isConsumed$98f8b0828fdde4a0)(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*paramString$af933b2f56e61fc3)(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
	void	(*setSource$4063475456b19564)(_jc_env *, struct _jc_java_awt_AWTEvent$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_java_awt_AWTEvent$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_java_awt_AWTEvent$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_EventObject$vmethods	java_util_EventObject;
	_jc_java_awt_AWTEvent$vmethods	java_awt_AWTEvent;
};

// Vtype
struct _jc_java_awt_AWTEvent$vtype {
	_jc_type			type;
	_jc_java_awt_AWTEvent$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_AWTEvent$sub_refs {
	_jc_byte_array	*bdata;
};

// Reference instance fields (object)
struct _jc_java_awt_AWTEvent$refs {
    _jc_java_awt_AWTEvent$sub_refs	java_awt_AWTEvent;
    _jc_java_util_EventObject$sub_refs	java_util_EventObject;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_AWTEvent$sub_nonrefs {
	jint	id;
	jboolean	consumed;
};

// Non-reference instance fields (object)
struct _jc_java_awt_AWTEvent$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_EventObject$sub_nonrefs	java_util_EventObject;
    _jc_java_awt_AWTEvent$sub_nonrefs	java_awt_AWTEvent;
};

// Object instance structure
struct _jc_java_awt_AWTEvent$object {
	_jc_java_awt_AWTEvent$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_AWTEvent$vtype	*vtype;
	_jc_java_awt_AWTEvent$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_AWTEvent$vtype _jc_java_awt_AWTEvent$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_AWTEvent, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_AWTEvent$class_object;

#endif	/* _JC_java_awt_AWTEvent_H_ */
